==> MSEtool_3.0.1.tar.gz: MSEtool/R/Data_documentation.R <==
# This file is automatically built by build_tools/build_data.r 
# Don't edit by hand!
# 

#' @rdname Stock-class-objects 
"Albacore"

#' @rdname Stock-class-objects 
"Blue_shark"

#' @rdname Stock-class-objects 
"Bluefin_tuna"

#' @rdname Stock-class-objects 
"Bluefin_tuna_WAtl"

#' @rdname Stock-class-objects 
"Butterfish"

#' @rdname Stock-class-objects 
"Herring"

#' @rdname Stock-class-objects 
"Mackerel"

#' @rdname Stock-class-objects 
"Porgy"

#' @rdname Stock-class-objects 
"Rockfish"

#' @rdname Stock-class-objects 
"Snapper"

#' @rdname Stock-class-objects 
"Sole"

#' @rdname Stock-class-objects 
"Toothfish"

#' Stock class objects
#' 
#' Example objects of class Stock
#' 
#' @name Stock-class-objects
#' @format NULL
#' @examples
#' avail("Stock")
NULL

#' @rdname Fleet-class-objects 
"DecE_Dom"

#' @rdname Fleet-class-objects 
"DecE_HDom"

#' @rdname Fleet-class-objects 
"DecE_NDom"

#' @rdname Fleet-class-objects 
"FlatE_Dom"

#' @rdname Fleet-class-objects 
"FlatE_HDom"

#' @rdname Fleet-class-objects 
"FlatE_NDom"

#' @rdname Fleet-class-objects 
"Generic_DecE"

#' @rdname Fleet-class-objects 
"Generic_FlatE"

#' @rdname Fleet-class-objects 
"Generic_Fleet"

#' @rdname Fleet-class-objects 
"Generic_IncE"

#' @rdname Fleet-class-objects 
"IncE_HDom"

#' @rdname Fleet-class-objects 
"IncE_NDom"

#' @rdname Fleet-class-objects 
"Low_Effort_Non_Target"

#' @rdname Fleet-class-objects 
"Target_All_Fish"

#' @rdname Fleet-class-objects 
"Targeting_Small_Fish"

#' Fleet class objects
#' 
#' Example objects of class Fleet
#' 
#' @name Fleet-class-objects
#' @format NULL
#' @examples
#' avail("Fleet")
NULL

#' @rdname Obs-class-objects 
"Generic_Obs"

#' @rdname Obs-class-objects 
"Imprecise_Biased"

#' @rdname Obs-class-objects 
"Imprecise_Unbiased"

#' @rdname Obs-class-objects 
"Perfect_Info"

#' @rdname Obs-class-objects 
"Precise_Biased"

#' @rdname Obs-class-objects 
"Precise_Unbiased"

#' Obs class objects
#' 
#' Example objects of class Obs
#' 
#' @name Obs-class-objects
#' @format NULL
#' @examples
#' avail("Obs")
NULL

#' @rdname Imp-class-objects 
"Overages"

#' @rdname Imp-class-objects 
"Perfect_Imp"

#' Imp class objects
#' 
#' Example objects of class Imp
#' 
#' @name Imp-class-objects
#' @format NULL
#' @examples
#' avail("Imp")
NULL

#'  DataSlots 
#'
#'  Dataframe with details of slots in Dat object
#'
#'
"DataSlots"


#' @rdname Data-class-objects 
"Atlantic_mackerel"

#' @rdname Data-class-objects 
"China_rockfish"

#' @rdname Data-class-objects 
"Cobia"

#' @rdname Data-class-objects 
"Example_datafile"

#' @rdname Data-class-objects 
"Gulf_blue_tilefish"

#' @rdname Data-class-objects 
"ourReefFish"

#' @rdname Data-class-objects 
"Red_snapper"

#' @rdname Data-class-objects 
"Simulation_1"

#' Data class objects
#' 
#' Example objects of class Data
#' 
#' @name Data-class-objects
#' @format NULL
#' @examples
#' avail("Data")
NULL

#' @rdname OM-class-objects 
"testOM"

#' OM class objects
#' 
#' Example objects of class OM
#' 
#' @name OM-class-objects
#' @format NULL
#' @examples
#' avail("OM")
NULL

#' @rdname MOM-class-objects 
"Albacore_TwoFleet"

#' MOM class objects
#' 
#' Example objects of class MOM
#' 
#' @name MOM-class-objects
#' @format NULL
#' @examples
#' avail("MOM")
NULL

#'  SimulatedData Data
#'
#'  An object of class Data
#'
"SimulatedData"


#'  ReqData 
#'
#'  Dataframe with required data slots for built-in MPs
#'
#'
"ReqData"


#'  LHdatabase 
#'
#'  Database from the FishLife package with predicted life-history parameters for all species on FishBase
#' 
#' @references Thorson, J. T., S. B. Munch, J. M. Cope, and J. Gao. 2017. 
#' Predicting life history parameters for all fishes worldwide. Ecological Applications. 27(8): 2262--2276  
#' @source \url{https://github.com/James-Thorson-NOAA/FishLife/} 
#'
#'
"LHdatabase"


#'  StockDescription 
#'
#'  A data.frame with description of slots for class Stock
#'
"StockDescription"


#'  FleetDescription 
#'
#'  A data.frame with description of slots for class Fleet
#'
"FleetDescription"


#'  ObsDescription 
#'
#'  A data.frame with description of slots for class Obs
#'
"ObsDescription"


#'  ImpDescription 
#'
#'  A data.frame with description of slots for class Imp
#'
"ImpDescription"


#'  DataDescription 
#'
#'  A data.frame with description of slots for class Data
#'
"DataDescription"


#'  OMDescription 
#'
#'  A data.frame with description of slots for class OM
#'
"OMDescription"


#'  MSEDescription 
#'
#'  A data.frame with description of slots for class MSE
#'
"MSEDescription"

==> MSEtool_3.7.2.tar.gz: MSEtool/R/Data_documentation.R <==
# This file is automatically built by build_tools/build_data.r 
# Don't edit by hand!
# 

#' @rdname Stock-class-objects 
"Albacore"

#' @rdname Stock-class-objects 
"Blue_shark"

#' @rdname Stock-class-objects 
"Bluefin_tuna"

#' @rdname Stock-class-objects 
"Bluefin_tuna_WAtl"

#' @rdname Stock-class-objects 
"Butterfish"

#' @rdname Stock-class-objects 
"Herring"

#' @rdname Stock-class-objects 
"Mackerel"

#' @rdname Stock-class-objects 
"Porgy"

#' @rdname Stock-class-objects 
"Rockfish"

#' @rdname Stock-class-objects 
"Snapper"

#' @rdname Stock-class-objects 
"Sole"

#' @rdname Stock-class-objects 
"Toothfish"

#' Stock class objects
#' 
#' Example objects of class Stock
#' 
#' @name Stock-class-objects
#' @format NULL
#' @examples
#' avail("Stock")
NULL

#' @rdname Fleet-class-objects 
"DecE_Dom"

#' @rdname Fleet-class-objects 
"DecE_HDom"

#' @rdname Fleet-class-objects 
"DecE_NDom"

#' @rdname Fleet-class-objects 
"FlatE_Dom"

#' @rdname Fleet-class-objects 
"FlatE_HDom"

#' @rdname Fleet-class-objects 
"FlatE_NDom"

#' @rdname Fleet-class-objects 
"Generic_DecE"

#' @rdname Fleet-class-objects 
"Generic_FlatE"

#' @rdname Fleet-class-objects 
"Generic_Fleet"

#' @rdname Fleet-class-objects 
"Generic_IncE"

#' @rdname Fleet-class-objects 
"IncE_HDom"

#' @rdname Fleet-class-objects 
"IncE_NDom"

#' @rdname Fleet-class-objects 
"Low_Effort_Non_Target"

#' @rdname Fleet-class-objects 
"Target_All_Fish"

#' @rdname Fleet-class-objects 
"Targeting_Small_Fish"

#' Fleet class objects
#' 
#' Example objects of class Fleet
#' 
#' @name Fleet-class-objects
#' @format NULL
#' @examples
#' avail("Fleet")
NULL

#' @rdname Obs-class-objects 
"Generic_Obs"

#' @rdname Obs-class-objects 
"Imprecise_Biased"

#' @rdname Obs-class-objects 
"Imprecise_Unbiased"

#' @rdname Obs-class-objects 
"Perfect_Info"

#' @rdname Obs-class-objects 
"Precise_Biased"

#' @rdname Obs-class-objects 
"Precise_Unbiased"

#' Obs class objects
#' 
#' Example objects of class Obs
#' 
#' @name Obs-class-objects
#' @format NULL
#' @examples
#' avail("Obs")
NULL

#' @rdname Imp-class-objects 
"Overages"

#' @rdname Imp-class-objects 
"Perfect_Imp"

#' Imp class objects
#' 
#' Example objects of class Imp
#' 
#' @name Imp-class-objects
#' @format NULL
#' @examples
#' avail("Imp")
NULL

#'  DataSlots 
#'
#'  Dataframe with details of slots in Dat object
#'
#'
"DataSlots"


#' @rdname Data-class-objects 
"Atlantic_mackerel"

#' @rdname Data-class-objects 
"China_rockfish"

#' @rdname Data-class-objects 
"Cobia"

#' @rdname Data-class-objects 
"Example_datafile"

#' @rdname Data-class-objects 
"Gulf_blue_tilefish"

#' @rdname Data-class-objects 
"ourReefFish"

#' @rdname Data-class-objects 
"Red_snapper"

#' @rdname Data-class-objects 
"Simulation_1"

#' Data class objects
#' 
#' Example objects of class Data
#' 
#' @name Data-class-objects
#' @format NULL
#' @examples
#' avail("Data")
NULL

#' @rdname OM-class-objects 
"testOM"

#' OM class objects
#' 
#' Example objects of class OM
#' 
#' @name OM-class-objects
#' @format NULL
#' @examples
#' avail("OM")
NULL

#' @rdname MOM-class-objects 
"Albacore_TwoFleet"

#' MOM class objects
#' 
#' Example objects of class MOM
#' 
#' @name MOM-class-objects
#' @format NULL
#' @examples
#' avail("MOM")
NULL

#'  SimulatedData Data
#'
#'  An object of class Data
#'
"SimulatedData"


#'  ReqData 
#'
#'  Dataframe with required data slots for built-in MPs
#'
#'
"ReqData"


#'  LHdatabase 
#'
#'  Database from the FishLife package with predicted life-history parameters for all species on FishBase
#' 
#' @references Thorson, J. T., S. B. Munch, J. M. Cope, and J. Gao. 2017. 
#' Predicting life history parameters for all fishes worldwide. Ecological Applications. 27(8): 2262--2276  
#' @source \url{https://github.com/James-Thorson-NOAA/FishLife/} 
#'
#'
"LHdatabase"


#'  StockDescription 
#'
#'  A data.frame with description of slots for class Stock
#'
"StockDescription"


#'  FleetDescription 
#'
#'  A data.frame with description of slots for class Fleet
#'
"FleetDescription"


#'  ObsDescription 
#'
#'  A data.frame with description of slots for class Obs
#'
"ObsDescription"


#'  ImpDescription 
#'
#'  A data.frame with description of slots for class Imp
#'
"ImpDescription"


#'  HistDescription 
#'
#'  A data.frame with description of slots for class Hist
#'
"HistDescription"


#'  DataDescription 
#'
#'  A data.frame with description of slots for class Data
#'
"DataDescription"


#'  OMDescription 
#'
#'  A data.frame with description of slots for class OM
#'
"OMDescription"


#'  MSEDescription 
#'
#'  A data.frame with description of slots for class MSE
#'
"MSEDescription"


#'  Taxa_Table 
#'
#'  Database from rfishbase 
#' 
#' @references Carl Boettiger and Duncan Temple Lang and Peter Wainwright
#' 2012. Journal of Fish Biology 
#' @source \doi{10.1111/j.1095-8649.2012.03464.x} 
#'
#'
"Taxa_Table"
